@@ -1,5 +1,5 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
-# Copyright 2019 Hewlett Packard Enterprise Development LP
+# Copyright 2019-2022 Hewlett Packard Enterprise Development LP
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -41,7 +41,8 @@ INFO_DICT = {
     "redfish_system_id": "/redfish/v1/Systems/Partition2",
     "enable_directed_lanboot": False,
     "enable_uefi_httpboot": False,
-    "boot_file_path": {"UrlBootFile": "tftp://1.1.1.4/tftpboot/bootx64.efi"}
+    "boot_file_path": {"UrlBootFile": "tftp://1.1.1.4/tftpboot/bootx64.efi"},
+    "http_boot_uri": "http://1.2.3.4/bootx64.efi"
 }
 sdflex_client = importutils.try_import('sdflexutils.redfish.client')
 sdflex_error = importutils.try_import('sdflexutils.exception')
@@ -58,14 +59,21 @@ class BaseSdflexTest(db_base.DbTestCase):
 
     boot_interface = None
     bios_interface = 'sdflex-redfish'
+    deploy_interface = 'sdflex-redfish'
 
     def setUp(self):
         super(BaseSdflexTest, self).setUp()
         self.config(enabled_hardware_types=['sdflex-redfish', 'fake-hardware'],
-                    enabled_boot_interfaces=['sdflex-redfish', 'fake'],
+                    enabled_boot_interfaces=['sdflex-redfish',
+                                             'sdflex-redfish-vmedia',
+                                             'sdflex-redfish-dhcpless',
+                                             'fake'],
                     enabled_power_interfaces=['sdflex-redfish', 'fake'],
                     enabled_bios_interfaces=['sdflex-redfish', 'fake'],
+                    enabled_deploy_interfaces=['sdflex-redfish', 'fake'],
                     enabled_management_interfaces=['sdflex-redfish', 'fake'],
+                    enabled_vendor_interfaces=['sdflex-redfish', 'redfish',
+                                               'no-vendor', 'fake'],
                     enabled_inspect_interfaces=['inspector', 'fake',
                                                 'no-inspect'])
         self.info = INFO_DICT.copy()
@@ -73,6 +81,7 @@ class BaseSdflexTest(db_base.DbTestCase):
             self.context, uuid=uuidutils.generate_uuid(),
             driver='sdflex-redfish', boot_interface=self.boot_interface,
             bios_interface=self.bios_interface,
+            deploy_interface=self.deploy_interface,
             driver_info=self.info)
 
 
@@ -266,6 +275,83 @@ class SdflexCommonMethodsTestCase(BaseSdflexTest):
             sdflex_object_mock.set_bios_settings.assert_called_once_with(
                 boot_file_path)
 
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_set_network_setting_dhcpless_boot(self, get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            network_data = {'links': [{'id': 'enp1s0', 'type': 'phy', 'ethernet_mac_address': '94:40:C9:D6:03:84', 'mtu': 1500}],  # noqa E501
+                            'networks': [{'id': 'provisioning IPv4', 'type': 'ipv4', 'link': 'enp1s0', 'ip_address': '10.229.136.128',  # noqa E501
+                                          'netmask': '255.255.248.0',
+                                          'routes': [{'network': '10.229.136.0', 'netmask': '255.255.248.0', 'gateway': '10.229.136.1'},  # noqa E501
+                                                     {'network': '0.0.0.0', 'netmask': '0.0.0.0', 'gateway': '10.229.136.1'}],  # noqa E501
+                                          'network_id': ''}],
+                            'services': [{'type': 'dns', 'address': '10.229.136.1'}]}  # noqa E501
+            task.node.update({'network_data': network_data})
+            url = 'http:/1.2.3.4/boot.iso'
+            expected_data = {'UrlBootFile': 'http:/1.2.3.4/boot.iso',
+                             'Ipv4Address': '10.229.136.128',
+                             'Ipv4Gateway': '10.229.136.1',
+                             'Ipv4SubnetMask': '255.255.248.0',
+                             'Dhcpv4': 'Disabled'}
+            sdflex_common.set_network_setting_dhcpless_boot(task.node, url)
+            sdflex_object_mock.set_bios_settings.assert_called_once_with(
+                expected_data)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_set_network_setting_dhcpless_boot_fail(self,
+                                                    get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        sdflex_object_mock.set_bios_settings.side_effect = (
+            sdflex_error.SDFlexError('error'))
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            network_data = {'links': [{'id': 'enp1s0', 'type': 'phy', 'ethernet_mac_address': '94:40:C9:D6:03:84', 'mtu': 1500}],  # noqa E501
+                            'networks': [{'id': 'provisioning IPv4', 'type': 'ipv4', 'link': 'enp1s0', 'ip_address': '10.229.136.128',  # noqa E501
+                                          'netmask': '255.255.248.0',
+                                          'routes': [{'network': '10.229.136.0', 'netmask': '255.255.248.0', 'gateway': '10.229.136.1'},  # noqa E501
+                                                     {'network': '0.0.0.0', 'netmask': '0.0.0.0', 'gateway': '10.229.136.1'}],  # noqa E501
+                                          'network_id': ''}],
+                            'services': [{'type': 'dns', 'address': '10.229.136.1'}]}  # noqa E501
+            task.node.update({'network_data': network_data})
+            url = 'http:/1.2.3.4/boot.iso'
+            self.assertRaises(exception.SDFlexOperationError,
+                              sdflex_common.set_network_setting_dhcpless_boot,
+                              task.node, url)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_reset_network_setting_dhcpless_boot(self, get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            bios_setting = {'UrlBootFile': '', 'Ipv4Address': '',
+                            'Ipv4Gateway': '', 'Ipv4SubnetMask': '',
+                            'Dhcpv4': 'Enabled'}
+            sdflex_common.reset_network_setting_dhcpless_boot(task.node)
+            sdflex_object_mock.set_bios_settings.assert_called_once_with(
+                bios_setting)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_reset_network_setting_dhcpless_boot_fail(self,
+                                                      get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        sdflex_object_mock.set_bios_settings.side_effect = (
+            sdflex_error.SDFlexError('error'))
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            bios_setting = {'UrlBootFile': '', 'Ipv4Address': '',
+                            'Ipv4Gateway': '', 'Ipv4SubnetMask': '',
+                            'Dhcpv4': 'Enabled'}
+            self.assertRaises(
+                exception.SDFlexOperationError,
+                sdflex_common.reset_network_setting_dhcpless_boot, task.node)
+            sdflex_object_mock.set_bios_settings.assert_called_once_with(
+                bios_setting)
+
     @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
                        autospec=True)
     def test_reset_bios_settings(self, get_sdflex_object_mock):
@@ -292,3 +378,56 @@ class SdflexCommonMethodsTestCase(BaseSdflexTest):
                               task.node)
             sdflex_object_mock.set_bios_settings.assert_called_once_with(
                 boot_file_path)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_enable_uefi_http_boot_file(self, get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            boot_file_path = task.node.driver_info['boot_file_path']
+            task.node.driver_info['http_boot_uri'] = None
+            sdflex_common.enable_uefi_http_boot(task.node)
+            sdflex_object_mock.set_bios_settings.assert_called_once_with(
+                boot_file_path)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_enable_uefi_http_boot_uri(self, get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            http_boot_uri = task.node.driver_info['http_boot_uri']
+            sdflex_common.enable_uefi_http_boot(task.node)
+            sdflex_object_mock.set_http_boot_uri.assert_called_once_with(
+                http_boot_uri)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_enable_uefi_http_boot_file_fail(self, get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        sdflex_object_mock.set_bios_settings.side_effect = (
+            sdflex_error.SDFlexError('error'))
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            boot_file_path = None
+            task.node.driver_info['boot_file_path'] = boot_file_path
+            task.node.driver_info['http_boot_uri'] = None
+            self.assertRaises(exception.SDFlexOperationError,
+                              sdflex_common.enable_uefi_http_boot,
+                              task.node)
+
+    @mock.patch.object(sdflex_common, 'get_sdflex_object', spec_set=True,
+                       autospec=True)
+    def test_enable_uefi_http_boot_uri_fail(self, get_sdflex_object_mock):
+        sdflex_object_mock = get_sdflex_object_mock.return_value
+        sdflex_object_mock.set_http_boot_uri.side_effect = (
+            sdflex_error.SDFlexError('error'))
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            set_http_boot_uri = None
+            task.node.driver_info['boot_file_path'] = None
+            task.node.driver_info['http_boot_uri'] = set_http_boot_uri
+            self.assertRaises(exception.SDFlexOperationError,
+                              sdflex_common.enable_uefi_http_boot,
+                              task.node)
